@@ -32,9 +32,6 @@
 */
 
 
-#include <stdio.h>
-#include <stdlib.h>
-
 #include "zipint.h"
 
 
