@@ -34,12 +34,6 @@
 
 #include <string.h>
 
-#include "compat.h"
-
-#ifdef HAVE_UNISTD_H
-#include <unistd.h>
-#endif
-
 #include "zipint.h"
 
 bool
